simpleMinimap_Compass = simpleMinimap:NewModule("compass")
local L = AceLibrary("AceLocale-2.2"):new("simpleMinimap_Compass")
L:RegisterTranslations("enUS", function() return({
	enabled = "enabled",
		enabled_desc = "enable / disable cardinal directions",
	compass = "compass",
		compass_desc = "NSEW markers on minimap",
	alpha = "alpha",
		alpha_desc = "set compass alpha",
	fontColor = "font color",
		fontColor_desc = "set the compass font color",
	north = "N",
	south = "S",
	east = "E",
	west = "W"
}) end)
--
function simpleMinimap_Compass:OnInitialize()
	self.db = simpleMinimap:AcquireDBNamespace("compass")
	self.defaults = { enabled=false, fontR=0.8, fontG=0.8, fontB=0.6, fotnA=1, shadow=true }
	self.options = {
		type="group", order=10, name=L.compass, desc=L.compass_desc,
		args={
			title = {
				type="header", order=1, name="simpleMinimap |cFFFFFFCC"..L.compass
			},
			spacer1={
				type="header", order=2
			},
			enabled={
				type="toggle", order=3, name= L.enabled, desc=L.enabled_desc,
				get=function() return(self.db.profile.enabled) end,
				set=function(x) self.db.profile.enabled=x simpleMinimap:ToggleModuleActive(self, x) end
			},
			spacer2={
				type="header", order=4, name="---"
			},
			fontColor={
				type="color", order=11, name=L.fontColor, desc=L.fontColor_desc,
				get = function() return self.db.profile.fontR, self.db.profile.fontG, self.db.profile.fontB end,
				set = function(r, g, b, a) self.db.profile.fontR=r self.db.profile.fontG=g self.db.profile.fontB=b self.db.profile.fontA=a self:UpdateScreen() end
			},
		}
	}
	simpleMinimap.options.args.compass = self.options
	simpleMinimap:RegisterDefaults("compass", "profile", self.defaults)
end
--
function simpleMinimap_Compass:OnEnable()
	if(self.db.profile.enabled) then
		if(not self.frames) then self.frames = {} end
		for dir, anc in pairs ({north="TOP", south="BOTTOM", east="RIGHT", west="LEFT"}) do
			if(not self.frames[dir]) then
				self.frames[dir] = simpleMinimap.frame:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall")
				self.frames[dir]:SetPoint("CENTER", Minimap, anc)
				self.frames[dir]:SetText(L[dir])
			end
		end
		self:UpdateScreen()
	else
		simpleMinimap:ToggleModuleActive(self, false)
	end
end
--
function simpleMinimap_Compass:OnDisable()
	self:UpdateScreen()
end
--
function simpleMinimap_Compass:UpdateScreen()
	if(self.frames) then
		for _, dir in pairs({"north", "south", "east", "west"}) do
			if(self.frames[dir]) then
				if(self.db.profile.enabled) then
					self.frames[dir]:Show()
					self.frames[dir]:SetTextColor(self.db.profile.fontR, self.db.profile.fontG, self.db.profile.fontB, self.db.profile.fontA)
					if(self.db.profile.shadow) then self.frames[dir]:SetShadowColor(1-self.db.profile.fontR, 1-self.db.profile.fontG, 1-self.db.profile.fontB, self.db.profile.fontA) end
				else
					if(self.frames[dir]) then self.frames[dir]:Hide() end
				end
			end
		end
	end
end